package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.WyPlatformBanner;

/**
 * platFormBannerMapper接口
 * 
 * @author ruoyi
 * @date 2025-01-05
 */
public interface WyPlatformBannerMapper 
{
    /**
     * 查询platFormBanner
     * 
     * @param id platFormBanner主键
     * @return platFormBanner
     */
    public WyPlatformBanner selectWyPlatformBannerById(Long id);

    /**
     * 查询platFormBanner列表
     * 
     * @param wyPlatformBanner platFormBanner
     * @return platFormBanner集合
     */
    public List<WyPlatformBanner> selectWyPlatformBannerList(WyPlatformBanner wyPlatformBanner);

    /**
     * 新增platFormBanner
     * 
     * @param wyPlatformBanner platFormBanner
     * @return 结果
     */
    public int insertWyPlatformBanner(WyPlatformBanner wyPlatformBanner);

    /**
     * 修改platFormBanner
     * 
     * @param wyPlatformBanner platFormBanner
     * @return 结果
     */
    public int updateWyPlatformBanner(WyPlatformBanner wyPlatformBanner);

    /**
     * 删除platFormBanner
     * 
     * @param id platFormBanner主键
     * @return 结果
     */
    public int deleteWyPlatformBannerById(Long id);

    /**
     * 批量删除platFormBanner
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyPlatformBannerByIds(Long[] ids);
}
